==> foundation-2.6.1.tgz: package/TorsosAllFemale/TorsosAllFemale.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const TorsosAllFemale = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M77.067 59.255L62.99 52.54l-5.754-2.745.301-.208h7.833a2.196 2.196 0 002.196-2.196v-5.779h-.02c-.228-7.653-2.767-14.425-6.622-18.894-2.71-3.484-6.605-5.681-10.971-5.681-4.732 0-8.911 2.586-11.625 6.593-3.435 4.452-5.664 10.833-5.877 17.982h-.02v5.779c0 1.213.983 2.196 2.196 2.196h7.855c.155.105.312.207.469.309L37.4 52.48l-14.534 6.768c-1.152.54-1.936 1.776-2.065 3.198a4.467 4.467 0 00-.046.626v16.005c0 2.146 1.495 3.884 3.34 3.884h51.806c1.846 0 3.34-1.739 3.34-3.884V63.072c0-.805-.212-1.563-.582-2.196-.359-.711-.907-1.29-1.592-1.621z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M25.646 52.52v-6.081h.027c.243-8.172 2.377-15.627 5.776-21.472-1.654-1.008-3.513-1.623-5.511-1.623-6.666 0-12.062 6.28-12.062 14.034 0 5.425 2.651 10.12 6.524 12.457l-16.349 7.61c-1.02.479-1.691 1.629-1.691 2.915v12.903c0 1.729 1.209 3.13 2.694 3.13h10.805v-13.54c0-3.503 1.938-6.672 4.943-8.08l4.844-2.253zm70.302 5.115L79.6 50.025c3.873-2.337 6.524-7.032 6.524-12.457 0-7.754-5.396-14.034-12.062-14.034-1.998 0-3.857.615-5.511 1.623 3.399 5.845 5.532 13.3 5.776 21.472h.027v6.081l4.844 2.256c3.005 1.407 4.943 4.576 4.943 8.08v13.54h10.805c1.485 0 2.694-1.401 2.694-3.13V60.55c-.001-1.286-.672-2.436-1.692-2.915z"
  }));
});
TorsosAllFemale.displayName = 'TorsosAllFemale';
export const TorsosAllFemaleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/TorsosAllFemale/TorsosAllFemale.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var TorsosAllFemale = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M77.067 59.255L62.99 52.54l-5.754-2.745.301-.208h7.833a2.196 2.196 0 002.196-2.196v-5.779h-.02c-.228-7.653-2.767-14.425-6.622-18.894-2.71-3.484-6.605-5.681-10.971-5.681-4.732 0-8.911 2.586-11.625 6.593-3.435 4.452-5.664 10.833-5.877 17.982h-.02v5.779c0 1.213.983 2.196 2.196 2.196h7.855c.155.105.312.207.469.309L37.4 52.48l-14.534 6.768c-1.152.54-1.936 1.776-2.065 3.198a4.467 4.467 0 00-.046.626v16.005c0 2.146 1.495 3.884 3.34 3.884h51.806c1.846 0 3.34-1.739 3.34-3.884V63.072c0-.805-.212-1.563-.582-2.196-.359-.711-.907-1.29-1.592-1.621z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M25.646 52.52v-6.081h.027c.243-8.172 2.377-15.627 5.776-21.472-1.654-1.008-3.513-1.623-5.511-1.623-6.666 0-12.062 6.28-12.062 14.034 0 5.425 2.651 10.12 6.524 12.457l-16.349 7.61c-1.02.479-1.691 1.629-1.691 2.915v12.903c0 1.729 1.209 3.13 2.694 3.13h10.805v-13.54c0-3.503 1.938-6.672 4.943-8.08l4.844-2.253zm70.302 5.115L79.6 50.025c3.873-2.337 6.524-7.032 6.524-12.457 0-7.754-5.396-14.034-12.062-14.034-1.998 0-3.857.615-5.511 1.623 3.399 5.845 5.532 13.3 5.776 21.472h.027v6.081l4.844 2.256c3.005 1.407 4.943 4.576 4.943 8.08v13.54h10.805c1.485 0 2.694-1.401 2.694-3.13V60.55c-.001-1.286-.672-2.436-1.692-2.915z"
  }));
});
TorsosAllFemale.displayName = 'TorsosAllFemale';
export var TorsosAllFemaleDimensions = {
  height: 100,
  width: 100
};
